@@ -1,5 +1,5 @@
 package Photonic::Geometry;
-$Photonic::Geometry::VERSION = '0.009';
+$Photonic::Geometry::VERSION = '0.010';
 use namespace::autoclean;
 use PDL::Lite;
 use PDL::NiceSlice;
@@ -43,6 +43,13 @@ has 'f'=>(is=>'ro', init_arg=>undef, lazy=>1, builder=>'_build_f',
 has 'unitPairs'=>(is=>'ro', isa=>'ArrayRef[PDL]', init_arg=>undef, lazy=>1,
      builder=>'_build_unitPairs', 
      documentation=>'Normalized sum of pairs of basis vectors');
+has 'CunitPairs'=>(is=>'ro', isa=>'ArrayRef[PDL]', init_arg=>undef, lazy=>1,
+     builder=>'_build_CunitPairs',
+     documentation=>'Normalized complex sum of pairs of basis vectors');
+has 'CCunitPairs'=>(is=>'ro', isa=>'ArrayRef[PDL]', init_arg=>undef, lazy=>1,
+     builder=>'_build_CCunitPairs',
+     documentation=>'Normalized complex-conjugate sum of pairs
+     of basis vectors');
 has 'unitDyads'=>(is=>'ro', isa=>'PDL', init_arg=>undef, lazy=>1,
      builder=>'_build_unitDyads',
      documentation=>'Matrix of dyads of unit vector pairs');
@@ -143,6 +150,39 @@ sub _build_unitPairs {
     return [@pairs];
 }
 
+sub _build_CunitPairs {
+    my $self=shift;
+    my $nd=$self->B->ndims;
+    my $units=$self->units;
+    my @cpairs;
+    for my $i(0..$nd-1){ #build pairs of vectors
+	for my $j($i+1..$nd-1){
+	    my $vc=($units->[$i]+i*$units->[$j]);
+	    my $vcn=sqrt(($units->[$i]+i*$units->[$j])->Cabs2->sumover);
+	    my $vp=$vc*(1/$vcn);
+	    push @cpairs, $vp;
+	}
+    }
+    return [@cpairs];
+}
+
+
+sub _build_CCunitPairs {
+    my $self=shift;
+    my $nd=$self->B->ndims;
+    my $units=$self->units;
+    my @ccpairs;
+    for my $i(0..$nd-1){ #build pairs of vectors
+	for my $j($i+1..$nd-1){
+	    my $vcc=($units->[$i]-i*$units->[$j]);
+	    my $vccn=sqrt(($units->[$i]-i*$units->[$j])->Cabs2->sumover);
+	    my $vm=$vcc*(1/$vccn);
+	    push @ccpairs, $vm;
+	}
+    }    
+    return [@ccpairs];
+}
+
 sub _build_unitDyads {
     my $self=shift;
     my $nd=$self->B->ndims; #Number of dimensions
@@ -174,7 +214,6 @@ sub _build_unitDyadsLU {
     return [($lu, $perm, $parity)];
 }
 
-
 sub _G0 {
     my $self=shift;
     my $value=shift;
@@ -229,7 +268,7 @@ Photonic::Geometry
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
